/****************************************************************************
** Meta object code from reading C++ file 'MarbleInputHandler.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../marble-26.04.2/src/lib/marble/MarbleInputHandler.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'MarbleInputHandler.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Marble18MarbleInputHandlerE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::MarbleInputHandler::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble18MarbleInputHandlerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::MarbleInputHandler",
        "lmbRequest",
        "",
        "rmbRequest",
        "mouseClickScreenPosition",
        "mouseMoveGeoPosition",
        "mouseClickGeoPosition",
        "GeoDataCoordinates::Unit",
        "restoreViewContext",
        "installPluginEventFilter",
        "RenderPlugin*",
        "renderPlugin"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'lmbRequest'
        QtMocHelpers::SignalData<void(int, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'rmbRequest'
        QtMocHelpers::SignalData<void(int, int)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'mouseClickScreenPosition'
        QtMocHelpers::SignalData<void(int, int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'mouseMoveGeoPosition'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'mouseClickGeoPosition'
        QtMocHelpers::SignalData<void(qreal, qreal, GeoDataCoordinates::Unit)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 }, { QMetaType::QReal, 2 }, { 0x80000000 | 7, 2 },
        }}),
        // Slot 'restoreViewContext'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'installPluginEventFilter'
        QtMocHelpers::SlotData<void(RenderPlugin *)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MarbleInputHandler, qt_meta_tag_ZN6Marble18MarbleInputHandlerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::MarbleInputHandler::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble18MarbleInputHandlerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble18MarbleInputHandlerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble18MarbleInputHandlerE_t>.metaTypes,
    nullptr
} };

void Marble::MarbleInputHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MarbleInputHandler *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->lmbRequest((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->rmbRequest((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 2: _t->mouseClickScreenPosition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 3: _t->mouseMoveGeoPosition((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->mouseClickGeoPosition((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<GeoDataCoordinates::Unit>>(_a[3]))); break;
        case 5: _t->restoreViewContext(); break;
        case 6: _t->installPluginEventFilter((*reinterpret_cast<std::add_pointer_t<RenderPlugin*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MarbleInputHandler::*)(int , int )>(_a, &MarbleInputHandler::lmbRequest, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleInputHandler::*)(int , int )>(_a, &MarbleInputHandler::rmbRequest, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleInputHandler::*)(int , int )>(_a, &MarbleInputHandler::mouseClickScreenPosition, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleInputHandler::*)(const QString & )>(_a, &MarbleInputHandler::mouseMoveGeoPosition, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MarbleInputHandler::*)(qreal , qreal , GeoDataCoordinates::Unit )>(_a, &MarbleInputHandler::mouseClickGeoPosition, 4))
            return;
    }
}

const QMetaObject *Marble::MarbleInputHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::MarbleInputHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble18MarbleInputHandlerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Marble::MarbleInputHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void Marble::MarbleInputHandler::lmbRequest(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void Marble::MarbleInputHandler::rmbRequest(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void Marble::MarbleInputHandler::mouseClickScreenPosition(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void Marble::MarbleInputHandler::mouseMoveGeoPosition(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Marble::MarbleInputHandler::mouseClickGeoPosition(qreal _t1, qreal _t2, GeoDataCoordinates::Unit _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3);
}
namespace {
struct qt_meta_tag_ZN6Marble25MarbleDefaultInputHandlerE_t {};
} // unnamed namespace

template <> constexpr inline auto Marble::MarbleDefaultInputHandler::qt_create_metaobjectdata<qt_meta_tag_ZN6Marble25MarbleDefaultInputHandlerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Marble::MarbleDefaultInputHandler",
        "installPluginEventFilter",
        "",
        "RenderPlugin*",
        "renderPlugin",
        "showLmbMenu",
        "showRmbMenu",
        "handlePressAndHold",
        "openItemToolTip",
        "setCursor",
        "QCursor",
        "lmbTimeout"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'installPluginEventFilter'
        QtMocHelpers::SlotData<void(RenderPlugin *)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'showLmbMenu'
        QtMocHelpers::SlotData<void(int, int)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::Int, 2 },
        }}),
        // Slot 'showRmbMenu'
        QtMocHelpers::SlotData<void(int, int)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::Int, 2 },
        }}),
        // Slot 'handlePressAndHold'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openItemToolTip'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setCursor'
        QtMocHelpers::SlotData<void(const QCursor &)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 2 },
        }}),
        // Slot 'lmbTimeout'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MarbleDefaultInputHandler, qt_meta_tag_ZN6Marble25MarbleDefaultInputHandlerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Marble::MarbleDefaultInputHandler::staticMetaObject = { {
    QMetaObject::SuperData::link<MarbleInputHandler::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble25MarbleDefaultInputHandlerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble25MarbleDefaultInputHandlerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Marble25MarbleDefaultInputHandlerE_t>.metaTypes,
    nullptr
} };

void Marble::MarbleDefaultInputHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MarbleDefaultInputHandler *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->installPluginEventFilter((*reinterpret_cast<std::add_pointer_t<RenderPlugin*>>(_a[1]))); break;
        case 1: _t->showLmbMenu((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 2: _t->showRmbMenu((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 3: _t->handlePressAndHold(); break;
        case 4: _t->openItemToolTip(); break;
        case 5: _t->setCursor((*reinterpret_cast<std::add_pointer_t<QCursor>>(_a[1]))); break;
        case 6: _t->lmbTimeout(); break;
        default: ;
        }
    }
}

const QMetaObject *Marble::MarbleDefaultInputHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Marble::MarbleDefaultInputHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Marble25MarbleDefaultInputHandlerE_t>.strings))
        return static_cast<void*>(this);
    return MarbleInputHandler::qt_metacast(_clname);
}

int Marble::MarbleDefaultInputHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MarbleInputHandler::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}
QT_WARNING_POP
