/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<MarbleMaps.h>)
#  include <MarbleMaps.h>
#endif
#if __has_include(<TextToSpeechClient.h>)
#  include <TextToSpeechClient.h>
#endif
#if __has_include(<config.h>)
#  include <config.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_marble_maps()
{
    qmlRegisterModule("org.kde.marble.maps", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<Config>("org.kde.marble.maps", 254);
    qmlRegisterEnum<Config::EnumProfile>("Config::EnumProfile");
    qmlRegisterTypesAndRevisions<Marble::MarbleMapsApplication>("org.kde.marble.maps", 254);
    qmlRegisterTypesAndRevisions<TextToSpeechClient>("org.kde.marble.maps", 254);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.marble.maps", 254, 254);
}

static const QQmlModuleRegistration orgkdemarblemapsRegistration("org.kde.marble.maps", qml_register_types_org_kde_marble_maps);
